@@ -67,7 +67,10 @@
 #import <AppKit/NSCIImageRep.h>
 #import <AppKit/NSClipView.h>
 #import <AppKit/NSCollectionView.h>
+#import <AppKit/NSCollectionViewFlowLayout.h>
+#import <AppKit/NSCollectionViewGridLayout.h>
 #import <AppKit/NSCollectionViewItem.h>
+#import <AppKit/NSCollectionViewLayout.h>
 #import <AppKit/NSColor.h>
 #import <AppKit/NSColorList.h>
 #import <AppKit/NSColorPanel.h>
@@ -164,6 +167,7 @@
 #import <AppKit/NSDockTile.h>
 #import <AppKit/NSDocument.h>
 #import <AppKit/NSDocumentController.h>
+#import <AppKit/NSDictionaryController.h>
 #import <AppKit/NSDrawer.h>
 #import <AppKit/NSFileWrapperExtensions.h>
 #import <AppKit/NSFontAssetRequest.h>
@@ -239,10 +243,13 @@
 #import <AppKit/NSSwitch.h>
 #import <AppKit/NSSplitViewController.h>
 #import <AppKit/NSSplitViewItem.h>
+#import <AppKit/NSTableCellView.h>
 #import <AppKit/NSTableColumn.h>
 #import <AppKit/NSTableHeaderCell.h>
 #import <AppKit/NSTableHeaderView.h>
+#import <AppKit/NSTableRowView.h>
 #import <AppKit/NSTableView.h>
+#import <AppKit/NSTableViewRowAction.h>
 #import <AppKit/NSTabView.h>
 #import <AppKit/NSTabViewController.h>
 #import <AppKit/NSTabViewItem.h>
