@@ -28,7 +28,7 @@
 
 #ifndef _GNUstep_H_NSMenu
 #define _GNUstep_H_NSMenu
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <Foundation/NSObject.h>
 #import <Foundation/NSGeometry.h>
@@ -386,6 +386,7 @@
  *  </enum>
  *
  */
+APPKIT_EXPORT_CLASS
 @interface NSMenu : NSObject <NSCoding, NSCopying>
 {
   NSString *_title;
@@ -435,9 +436,14 @@
 #endif
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+// Provided for source compatibility with GNUstep-specific code.
+// This method is just an alternate name for popUpMenuPositioningItem:atLocation:inView:
 - (void) popUpMenuPositionItem: (NSMenuItem *)item
                     atLocation: (NSPoint) point
                         inView: (NSView *) view;
+- (void) popUpMenuPositioningItem: (NSMenuItem *)item
+                       atLocation: (NSPoint) point
+                           inView: (NSView *) view;
 #endif
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_2, GS_API_LATEST)
@@ -632,6 +638,12 @@
  */
 - (void) removeItemAtIndex: (NSInteger)index;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+/** Removes all items
+ */
+- (void) removeAllItems;
+#endif
+
 /** Sets if a menu does autoenable.
  */
 - (void) setAutoenablesItems: (BOOL)flag;
