@@ -33,15 +33,18 @@
 #import <AppKit/NSControl.h>
 #import <AppKit/NSDragging.h>
 #import <AppKit/NSUserInterfaceValidation.h>
+#import <AppKit/NSUserInterfaceItemIdentification.h>
 
 @class NSArray;
 @class NSIndexSet;
 @class NSMutableIndexSet;
 @class NSTableColumn;
 @class NSTableHeaderView;
+@class NSTableRowView;
 @class NSText;
 @class NSImage;
 @class NSURL;
+@class NSNib;
 
 typedef enum _NSTableViewDropOperation {
   NSTableViewDropOn,
@@ -88,9 +91,19 @@ typedef enum _NSTableViewAnimationOptions
   NSTableViewAnimationSlideLeft  = 0x30,
   NSTableViewAnimationSlideRight = 0x40,
 } NSTableViewAnimationOptions;
+
+typedef enum _NSTableViewRowSizeStyle
+{
+  NSTableViewRowSizeStyleDefault = -1,
+  NSTableViewRowSizeStyleCustom = 0,
+  NSTableViewRowSizeStyleSmall = 1,
+  NSTableViewRowSizeStyleMedium = 2,
+  NSTableViewRowSizeStyleLarge = 3,
+} NSTableViewRowSizeStyle;
 #endif
 
 
+APPKIT_EXPORT_CLASS
 @interface NSTableView : NSControl <NSUserInterfaceValidations>
 {
   /*
@@ -124,6 +137,7 @@ typedef enum _NSTableViewAnimationOptions
   BOOL               _allowsColumnReordering;
   BOOL               _autoresizesAllColumnsToFit;
   BOOL               _selectingColumns;
+  BOOL               _usesAlternatingRowBackgroundColors;
   NSText            *_textObject;
   NSInteger          _editedRow;
   NSInteger          _editedColumn;
@@ -154,7 +168,8 @@ typedef enum _NSTableViewAnimationOptions
    * We cache column origins (precisely, the x coordinate of the left
    * origin of each column).  When a column width is changed through
    * [NSTableColumn setWidth:], then [NSTableView tile] gets called,
-   * which updates the cache.  */
+   * which updates the cache.
+   */
   CGFloat *_columnOrigins;
 
   /*
@@ -173,6 +188,13 @@ typedef enum _NSTableViewAnimationOptions
   NSDragOperation _draggingSourceOperationMaskForRemote;
 
   NSInteger _beginEndUpdates;
+
+  /* Supporting ivars for view based tables */
+  BOOL _viewBased;
+  NSMapTable *_renderedViewPaths;
+  NSMapTable *_pathsToViews;
+  NSMutableDictionary *_registeredNibs;
+  NSMutableDictionary *_registeredViews;
 }
 
 /* Data Source */
@@ -379,6 +401,13 @@ typedef enum _NSTableViewAnimationOptions
 - (void) insertRowsAtIndexes: (NSIndexSet*)indexes withAnimation: (NSTableViewAnimationOptions)animationOptions;
 - (void) removeRowsAtIndexes: (NSIndexSet*)indexes withAnimation: (NSTableViewAnimationOptions)animationOptions;
 - (NSInteger) rowForView: (NSView*)view;
+- (NSView *) makeViewWithIdentifier: (NSUserInterfaceItemIdentifier)identifier owner: (id)owner;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_8, GS_API_LATEST)
+- (void) registerNib: (NSNib *)nib
+       forIdentifier: (NSUserInterfaceItemIdentifier)identifier;
+- (NSDictionary *) registeredNibsByIdentifier;
 #endif
 
 @end /* interface of NSTableView */
@@ -496,6 +525,24 @@ dataCellForTableColumn: (NSTableColumn *)aTableColumn
                      row: (NSInteger)row
            mouseLocation: (NSPoint)mouse;
 #endif
+
+// NSTableCellView based table methods...
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+- (NSView *) tableView: (NSTableView *)tableView
+    viewForTableColumn: (NSTableColumn *)aTableColumn
+                   row: (NSInteger)rowIndex;
+
+- (NSTableRowView *) tableView: (NSTableView *)tableView
+                 rowViewForRow: (NSInteger)rowIndex;
+
+- (void) tableView: (NSTableView *)tableView
+     didAddRowView: (NSTableRowView *)rowView
+            forRow: (NSInteger)rowIndex;
+
+- (void) tableView: (NSTableView *)tableView
+  didRemoveRowView: (NSTableRowView *)rowView
+            forRow: (NSInteger)rowIndex;
+#endif
 @end
 
 #endif /* _GNUstep_H_NSTableView */
