@@ -2,9 +2,11 @@
 
    <abstract>ImageMagick image representation.</abstract>
 
-   Copyright (C) 2011 Free Software Foundation, Inc.
+   Copyright (C) 2011-2024 Free Software Foundation, Inc.
    
    Author:  Eric Wasylishen <ewasylishen@gmail.com>
+            Riccardo Mottola
+
    Date: June 2011
    
    This file is part of the GNUstep Application Kit Library.
@@ -43,7 +45,11 @@
 
 #if HAVE_IMAGEMAGICK
 
+#if MAGICKCORE_7_OR_NEWER
+#include <MagickCore/MagickCore.h>
+#else
 #include <magick/MagickCore.h>
+#endif
 
 @implementation GSImageMagickImageRep 
 
@@ -119,13 +125,17 @@
   return bmp;
 }
 
+#define SIGNATURE_LENGTH 18
+
 + (NSArray*) imageRepsWithData: (NSData *)data allImages: (BOOL)allImages
 {
   NSMutableArray *reps = [NSMutableArray array];
 
   ExceptionInfo *exception = AcquireExceptionInfo();
   ImageInfo *imageinfo = CloneImageInfo(NULL);
-  Image *images, *image;
+  Image *images;
+  Image *image;
+  char signature[SIGNATURE_LENGTH];
   
   // Set the background color to transparent
   // (otherwise SVG's are rendered against a white background by default)
@@ -135,6 +145,14 @@
   QueryColorDatabase("none", &imageinfo->background_color, exception);
 #endif
 
+  memset(signature, 0, SIGNATURE_LENGTH);
+  [data getBytes: signature range: NSMakeRange([data length] - 18, 18)];
+  if (strncmp(signature, "TRUEVISION-XFILE.", 17) == 0)
+    {
+      NSWarnLog(@"Targa file detected!, giving a magick hint...");
+      strcpy(imageinfo->magick, "TGA");
+    }
+
   images = BlobToImage(imageinfo, [data bytes], [data length], exception);
 
   if (exception->severity != UndefinedException)
