@@ -38,6 +38,11 @@
 #import "GNUstepGUI/GSModelLoaderFactory.h"
 
 @implementation GSModelLoader
++ (BOOL) canReadData: (NSData *)theData
+{
+  return NO;
+}
+
 + (NSString *) type
 {
   return nil;
@@ -103,6 +108,7 @@
 static NSMutableDictionary *_modelMap = nil;
 
 @implementation GSModelLoaderFactory
+
 + (void) initialize
 {
   NSArray *classes = GSObjCAllSubclassesOfClass([GSModelLoader class]);
@@ -216,4 +222,23 @@ static NSMutableDictionary *_modelMap = nil;
   
   return result;  
 }
+
++ (GSModelLoader *) modelLoaderForData: (NSData *)theData
+{
+  NSEnumerator *oen = [_modelMap objectEnumerator];
+  Class aClass = nil;
+  GSModelLoader *result = nil;
+  
+  while ((aClass = [oen nextObject]) != nil)
+    {
+      if ([aClass canReadData: theData])
+        {
+          result = AUTORELEASE([[aClass alloc] init]);
+          break;
+        }
+    }
+
+  return result;
+}
+
 @end
