@@ -37,11 +37,17 @@
 #import "AppKit/NSEvent.h"
 #import "AppKit/NSWindow.h"
 
+#import "GSFastEnumeration.h"
+
 //
 // class variables
 //
 static id buttonCellClass = nil;
 
+@interface NSButtonCell (_NSButton_Private_)
+- (BOOL) _isRadio;
+@end
+
 /**
    TODO Description
 */
@@ -543,4 +549,49 @@ static id buttonCellClass = nil;
   return [_cell sound];
 }
 
+// Implement 10.7+ radio button behavior
+- (void) _flipState: (NSButton *)b
+{
+  if ([[b cell] _isRadio])
+    {
+      if ([self action] == [b action] && b != self)
+        {
+          [b setState: NSOffState];
+        }
+    }
+}
+
+- (void) _handleRadioStates
+{
+  if ([[self cell] _isRadio] == NO)
+    return;
+  else
+    {
+      NSView *sv = [self superview];
+      NSArray *subviews = [sv subviews];
+  
+      FOR_IN(NSView*, v, subviews)
+        {
+          if ([v isKindOfClass: [NSButton class]])
+            {
+              NSButton *b = (NSButton *)v;
+              [self _flipState: b];
+            }
+        }
+      END_FOR_IN(subviews);
+    }
+}
+
+- (BOOL) sendAction: (SEL)theAction to: (id)theTarget
+{
+  BOOL flag = [super sendAction: theAction
+                             to: theTarget];
+  if (flag == YES)
+    {
+      [self _handleRadioStates];
+    }
+  
+  return flag;
+}
+
 @end
