@@ -93,8 +93,8 @@
       pixelsWide <= 0 || pixelsHigh <= 0)
     {
       [NSException raise: NSInvalidArgumentException
-		  format: @"NSCachedImageRep created with size %@ pixelsWide %d pixelsHigh %d",
-		   NSStringFromSize(aSize), pixelsWide, pixelsHigh];
+		  format: @"NSCachedImageRep created with size %@ pixelsWide %li pixelsHigh %li",
+		   NSStringFromSize(aSize), (long int) pixelsWide, (long int) pixelsHigh];
     }
 
   // FIXME: Only create new window when separate is YES
