@@ -1546,7 +1546,7 @@ static inline NSRect buttonCellFrameFromRect(NSRect cellRect)
   if ([coder allowsKeyedCoding])
     {
       [coder encodeBool: [self hasVerticalScroller] forKey: @"NSHasVerticalScroller"];
-      [coder encodeInt: [self numberOfVisibleItems] forKey: @"NSVisibleItemCount"];
+      [coder encodeInteger: [self numberOfVisibleItems] forKey: @"NSVisibleItemCount"];
       [coder encodeBool: [self completes] forKey: @"NSCompletes"];
       [coder encodeDouble: _intercellSpacing.width forKey: @"NSIntercellSpacingWidth"];
       [coder encodeDouble: _intercellSpacing.height forKey: @"NSIntercellSpacingHeight"];
@@ -1562,10 +1562,10 @@ static inline NSRect buttonCellFrameFromRect(NSRect cellRect)
       [coder encodeValueOfObjCType: @encode(BOOL) at: &_hasVerticalScroller];
       [coder encodeValueOfObjCType: @encode(BOOL) at: &_completes];
       [coder encodeValueOfObjCType: @encode(BOOL) at: &_usesDataSource];
-      [coder encodeValueOfObjCType: @encode(int) at: &_visibleItems];
+      encode_NSInteger(coder, &_visibleItems);
       [coder encodeValueOfObjCType: @encode(NSSize) at: &_intercellSpacing];
       [coder encodeValueOfObjCType: @encode(float) at: &_itemHeight];
-      [coder encodeValueOfObjCType: @encode(int) at: &_selectedItem];
+      encode_NSInteger(coder, &_selectedItem);
       
       if (_usesDataSource == YES)
 	[coder encodeConditionalObject: _dataSource];      
@@ -1596,7 +1596,7 @@ static inline NSRect buttonCellFrameFromRect(NSRect cellRect)
 	}
       if ([aDecoder containsValueForKey: @"NSVisibleItemCount"])
         {
-	  [self setNumberOfVisibleItems: [aDecoder decodeIntForKey: 
+	  [self setNumberOfVisibleItems: [aDecoder decodeIntegerForKey:
 						       @"NSVisibleItemCount"]];
 	}
       if ([aDecoder containsValueForKey: @"NSCompletes"])
@@ -1649,10 +1649,10 @@ static inline NSRect buttonCellFrameFromRect(NSRect cellRect)
       [aDecoder decodeValueOfObjCType: @encode(BOOL) at: &_hasVerticalScroller];
       [aDecoder decodeValueOfObjCType: @encode(BOOL) at: &_completes];
       [aDecoder decodeValueOfObjCType: @encode(BOOL) at: &dummy];
-      [aDecoder decodeValueOfObjCType: @encode(int) at: &_visibleItems];
+      decode_NSInteger(aDecoder, &_visibleItems);
       [aDecoder decodeValueOfObjCType: @encode(NSSize) at: &_intercellSpacing];
       [aDecoder decodeValueOfObjCType: @encode(float) at: &_itemHeight];
-      [aDecoder decodeValueOfObjCType: @encode(int) at: &_selectedItem];
+      decode_NSInteger(aDecoder, &_selectedItem);
 
       if (_usesDataSource == YES)
 	[self setDataSource: [aDecoder decodeObject]];      
