@@ -60,6 +60,41 @@ BOOL NSImageForceCaching = NO; /* use on missmatch */
 
 static NSDictionary		*nsmapping = nil;
 
+// OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+NSString *const NSImageNameQuickLookTemplate        = @"NSQuickLookTemplate";
+NSString *const NSImageNameBluetooth                = @"NSBluetoothTemplate";
+NSString *const NSImageNameIChatTheater             = @"NSIChatTheaterTemplate";
+NSString *const NSImageNameSlideshow                = @"NSSlideshowTemplate";
+NSString *const NSImageNameAction                   = @"NSActionTemplate";
+NSString *const NSImageNameSmartBadge               = @"NSSmartBadgeTemplate";
+NSString *const NSImageNameIconView                 = @"NSIconViewTemplate";
+NSString *const NSImageNameListView                 = @"NSListViewTemplate";
+NSString *const NSImageNameColumnView               = @"NSColumnViewTemplate";
+NSString *const NSImageNameFlowView                 = @"NSFlowViewTemplate";
+NSString *const NSImageNamePath                     = @"NSPathTemplate";
+NSString *const NSImageNameInvalidDataFreestanding  = @"NSInvalidDataFreestandingTemplate";
+NSString *const NSImageNameLockLocked               = @"NSLockLockedTemplate";
+NSString *const NSImageNameLockUnlocked             = @"NSLockUnlockedTemplate";
+NSString *const NSImageNameGoRight                  = @"NSGoRightTemplate";
+NSString *const NSImageNameGoLeft                   = @"NSGoLeftTemplate";
+NSString *const NSImageNameRightFacingTriangle      = @"NSRightFacingTriangleTemplate";
+NSString *const NSImageNameLeftFacingTriangle       = @"NSLeftFacingTriangleTemplate";
+NSString *const NSImageNameAdd                      = @"NSAddTemplate";
+NSString *const NSImageNameRemove                   = @"NSRemoveTemplate";
+NSString *const NSImageNameRevealFreestanding       = @"NSRevealFreestandingTemplate";
+NSString *const NSImageNameFollowLinkFreestanding   = @"NSFollowLinkFreestandingTemplate";
+NSString *const NSImageNameEnterFullScreen          = @"NSEnterFullScreenTemplate";
+NSString *const NSImageNameExitFullScreen           = @"NSExitFullScreenTemplate";
+NSString *const NSImageNameStopProgress             = @"NSStopProgressTemplate";
+NSString *const NSImageNameStopProgressFreestanding = @"NSStopProgressFreestandingTemplate";
+NSString *const NSImageNameRefresh                  = @"NSRefreshTemplate";
+NSString *const NSImageNameRefreshFreestanding      = @"NSRefreshFreestandingTemplate";
+NSString *const NSImageNameBonjour                  = @"NSBonjour";
+NSString *const NSImageNameComputer                 = @"NSComputer";
+NSString *const NSImageNameFolderBurnable           = @"NSFolderBurnable";
+NSString *const NSImageNameFolderSmart              = @"NSFolderSmart";
+NSString *const NSImageNameNetwork                  = @"NSNetwork";
+
 @interface NSView (Private)
 - (void) _lockFocusInContext: (NSGraphicsContext *)ctxt inRect: (NSRect)rect;
 @end
@@ -1932,15 +1967,25 @@ static NSSize GSResolutionOfImageRep(NSImageRep *rep)
 - (id) initWithCoder: (NSCoder*)coder
 {
   BOOL flag;
-
+  
   _reps = [[NSMutableArray alloc] initWithCapacity: 2];
   if ([coder allowsKeyedCoding])
     {
       if ([coder containsValueForKey: @"NSName"])
         {
-          RELEASE(self);
-          return RETAIN([NSImage imageNamed:
-            [coder decodeObjectForKey: @"NSName"]]);
+          NSImage *replacementImage;
+          NSString *imageName;
+
+          imageName = [coder decodeObjectForKey: @"NSName"];
+          replacementImage = [NSImage imageNamed: imageName];
+          if (replacementImage)
+            {
+              RELEASE(self);
+              return RETAIN(replacementImage);
+            }
+
+          [self setName: imageName];
+          self->_flags.archiveByName = YES;
         }
       if ([coder containsValueForKey: @"NSColor"])
         {
@@ -2017,10 +2062,20 @@ static NSSize GSResolutionOfImageRep(NSImageRep *rep)
       [coder decodeValueOfObjCType: @encode(BOOL) at: &flag];
       if (flag == YES)
         {
+          NSImage *replacementImage;
           NSString *theName = [coder decodeObject];
 
-          RELEASE(self);
-          self = RETAIN([NSImage imageNamed: theName]);
+          replacementImage = [NSImage imageNamed: theName];
+          if (replacementImage)
+            {
+              RELEASE(self);
+              self = RETAIN(replacementImage);
+            }
+          else
+            {
+              [self setName: theName];
+              self->_flags.archiveByName = YES;
+            }
         }
       else
         {
