@@ -283,13 +283,15 @@ static NSString *commandKeyString = @"#";
       else
         {
           // shift mask and not an upper case string?
-          shift = (m & NSShiftKeyMask) & ![key isEqualToString: ucKey];
+          shift = (m & NSShiftKeyMask) && ![key isEqualToString: ucKey];
           key = [NSString stringWithFormat:@"%@%@%@%@%@",
                           (m & NSControlKeyMask) ? controlKeyString : @"",
                           (m & NSAlternateKeyMask) ? alternateKeyString : @"",
                           (shift != NO) ? shiftKeyString : @"",
                           (m & NSCommandKeyMask) ? commandKeyString : @"",
                           key];
+
+	  key = [[GSTheme theme] keyForKeyEquivalent: key];
         }
     }
 
