@@ -8,18 +8,18 @@
  * This file is part of GNUstep.
  * 
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110 
  * USA.
  */
 
@@ -298,7 +298,7 @@
   return self;
 }
 
-- (id) copyWithZone: (NSZone *)zone;
+- (id) copyWithZone: (NSZone *)zone
 {
   NSSegmentedCell *c = (NSSegmentedCell *)[super copyWithZone: zone];
   
