@@ -141,7 +141,7 @@ static NSNotificationCenter *nc = nil;
  *	The range argument to edited:... is the range in the original string
  *	(before the edit).
  */
-- (void) edited: (unsigned)mask range: (NSRange)old changeInLength: (int)delta
+- (void) edited: (NSTextStorageEditedOptions)mask range: (NSRange)old changeInLength: (NSInteger)delta
 {
 
   NSDebugLLog(@"NSText", @"edited:range:changeInLength: called");
@@ -191,9 +191,9 @@ static NSNotificationCenter *nc = nil;
 - (void) processEditing
 {
   NSRange	r;
-  int original_delta;
+  NSInteger original_delta;
   unsigned int i;
-  unsigned length;
+  NSUInteger length;
 
   NSDebugLLog(@"NSText", @"processEditing called in NSTextStorage.");
 
@@ -253,6 +253,21 @@ static NSNotificationCenter *nc = nil;
 	}
     }
 
+  /*
+   * we make a local copy to ensure recursing in layoutManagers has
+   * correct values
+   */
+  NSRange editedRange = _editedRange;
+  NSInteger editedDelta = _editedDelta;
+  NSTextStorageEditedOptions editedMask = _editedMask;
+
+  /*
+   * edited values reset to be used again in the next pass.
+   */
+  _editedRange = NSMakeRange (0, 0);
+  _editedDelta = 0;
+  _editedMask = 0;
+
   /*
    * Calls textStorage:edited:range:changeInLength:invalidatedRange: for
    * every layoutManager.
@@ -262,17 +277,10 @@ static NSNotificationCenter *nc = nil;
     {
       GSLayoutManager *lManager = [_layoutManagers objectAtIndex: i];
 
-      [lManager textStorage: self  edited: _editedMask  range: r
-		changeInLength: _editedDelta  invalidatedRange: _editedRange];
+      [lManager textStorage: self  edited: editedMask  range: r
+		changeInLength: editedDelta  invalidatedRange: editedRange];
     }
 
-  /*
-   * edited values reset to be used again in the next pass.
-   */
-
-  _editedRange = NSMakeRange (0, 0);
-  _editedDelta = 0;
-  _editedMask = 0;
 }
 
 /*
@@ -281,7 +289,7 @@ static NSNotificationCenter *nc = nil;
  *	during processEditing... editedRange.location will be NSNotFound if
  *	nothing has been edited.
  */       
-- (unsigned) editedMask
+- (NSTextStorageEditedOptions) editedMask
 {
   return _editedMask;
 }
@@ -291,7 +299,7 @@ static NSNotificationCenter *nc = nil;
   return _editedRange;
 }
 
-- (int) changeInLength
+- (NSInteger) changeInLength
 {
   return _editedDelta;
 }
