@@ -28,6 +28,7 @@
 #define _GNUstep_H_NSViewPrivate
 
 #import "AppKit/NSView.h"
+#import "GSAutoLayoutEngine.h"
 
 @interface NSView (KeyViewLoop)
 - (void) _setUpKeyViewLoopWithNextKeyView: (NSView *)nextKeyView;
@@ -38,4 +39,16 @@
 - (void) _insertSubview: (NSView *)sv atIndex: (NSUInteger)idx;
 @end
 
+@interface NSView (NSConstraintBasedLayoutCorePrivateMethods)
+
+- (void) _setNeedsUpdateConstraints: (BOOL)needsUpdateConstraints;
+
+- (void) _layoutViewAndSubViews;
+
+- (GSAutoLayoutEngine*) _layoutEngine;
+
+- (void) _layoutEngineDidChangeAlignmentRect;
+
+@end
+
 #endif // _GNUstep_H_NSViewPrivate
